@@ -16,7 +16,7 @@
 from typing import Generic, List, Optional, TypeVar
 from uuid import UUID
 
-from core.exception.exceptions import EntityNotFoundError
+from hspylib.core.exception.exceptions import EntityNotFoundError
 
 E = TypeVar('E')
 R = TypeVar('R')
